@@ -13,18 +13,13 @@
 ##############################################################################
 """Test hookup
 
-$Id: tests.py 75668 2007-05-10 09:51:52Z zagy $
+$Id: tests.py 111678 2010-04-30 17:59:46Z hannosch $
 """
-import unittest
 
-from zope.testing import doctest
+import doctest
 
 
 def test_suite():
     return doctest.DocFileSuite(
         'property.txt', 'method.txt',
         optionflags=doctest.ELLIPSIS)
-
-
-if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
